@@ -5,6 +5,7 @@
 #include <list>
 #include <vector>
 #include <random>     // for random shuffle
+#include <memory>
 
 #include <algorithm>
 #include <string>
@@ -17,10 +18,10 @@ using namespace std;
 class Board {
 private:
   int nSpaces;
-  std::vector<Space*> spaces;
+  std::vector<std::shared_ptr<Space>> spaces;
   std::vector<Die> dice;
   // std::vector<Camel> camels;
-  std::map<std::string, Camel*> camels;
+  std::map<std::string, std::shared_ptr<Camel>> camels;
   std::vector<std::string> colors;
   bool debug;
   std::vector<std::string> ranking;
@@ -31,6 +32,8 @@ public:
 
   Board(const Board & b);
 
+  ~Board(){}
+
   int getNDiceRemaining();
 
   void resetDice();
@@ -49,13 +52,13 @@ public:
 
   std::vector<std::string> getRanking();
 
-  Camel* getCamel(std::string color);
+  std::shared_ptr<Camel> getCamel(std::string color);
 
-  void placePlusTile(int n, Player* p);
+  void placePlusTile(int n, std::shared_ptr<Player> p);
 
-  void placeMinusTile(int n, Player* p);
+  void placeMinusTile(int n, std::shared_ptr<Player> p);
 
-  Space* getSpaceN(int n);
+  std::shared_ptr<Space> getSpaceN(int n);
 
   std::vector<Die> getDice();
 
